@@ -1,13 +1,13 @@
 from typing import List
 import httpx
 import traceback
-import json
 import re
 from requests import head
 from .data_source import servers
 from .wws_info import get_AccountIdByName
 from .utils import match_keywords
 from nonebot import get_driver
+from nonebot.log import logger
 
 headers = {
     'Authorization': get_driver().config.api_token
@@ -15,6 +15,7 @@ headers = {
 
 async def get_BindInfo(user,info):
     try:
+        url,params = '',''
         if isinstance(info,List) and len(info) == 1:
             for i in info:              #是否包含me或@
                 if i == 'me':
@@ -31,10 +32,14 @@ async def get_BindInfo(user,info):
                     "platformId": match.group(1),
                     }
                     break
+            if not url or not params:
+                return '参数似乎出了问题呢，请使用me或@群友'
         else:
             return '参数似乎出了问题呢，请使用me或@群友'
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=10)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['message'] == "success":
             if result['data']:
@@ -51,9 +56,9 @@ async def get_BindInfo(user,info):
             else:
                 return '该用户似乎还没绑定窝窝屎账号'
         else:
-            return result['message']
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
     except Exception:
-        traceback.print_exc()
+        logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
     
 async def set_BindInfo(user,info):
@@ -72,24 +77,26 @@ async def set_BindInfo(user,info):
                         "accountId": param_accountid
                         }
                     else:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
+                        return '无法查询该游戏昵称Orz，请检查昵称是否存在，也有可能是网络波动，请稍后再试'
                 else:
                     return '服务器参数似乎输错了呢'
             else:
                 return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
         else:
             return '参数似乎输错了呢，请确保后面跟随服务器+游戏昵称'
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=20)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['message'] == "success":
             return '绑定成功'
         elif result['code'] == 500:
-            return result['message']
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return 'wuwuwu出了点问题，请联系麻麻解决'
     except Exception:
-        traceback.print_exc()
+        logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
 
 async def change_BindInfo(user,info):
@@ -102,8 +109,10 @@ async def change_BindInfo(user,info):
             }
         else:
             return '参数似乎出了问题呢，请跟随要切换的序号'
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=10)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['message'] == "success":
             if result['data'] and len(result['data']) >= int(info[0]):
@@ -131,9 +140,9 @@ async def change_BindInfo(user,info):
         elif result['code'] == 404:
             return f"{result['message']}"
         elif result['code'] == 500:
-            return f"{result['message']}"
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return 'wuwuwu出了点问题，请联系麻麻解决'
     except Exception:
-        traceback.print_exc()
+        logger.error(traceback.format_exc())
         return 'wuwuwu出了点问题，请联系麻麻解决'
\ No newline at end of file
