@@ -1,15 +1,16 @@
 from typing import List
 import httpx
 import traceback
-import json
 import jinja2
 import time
 import re
 from pathlib import Path
 from .data_source import servers,set_recentparams
-from .utils import html_to_pic,match_keywords
+from .utils import match_keywords
+from nonebot_plugin_htmlrender import html_to_pic
 from .wws_info import get_AccountIdByName
 from nonebot import get_driver
+from nonebot.log import logger
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
@@ -24,6 +25,7 @@ headers = {
 
 async def get_RecentInfo(qqid,info):
     try:
+        url,params = '',''
         params,day = None,1
         if isinstance(info,List):
             for i in info:              #查找日期,没找到默认一天
@@ -59,18 +61,19 @@ async def get_RecentInfo(qqid,info):
                         "seconds": int(time.time())-86400*int(day)
                         }
                     else:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
+                        return '无法查询该游戏昵称Orz，请检查昵称是否存在，也有可能是网络波动，请稍后再试'
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
-                print('下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦')
+                print(params)
             else:
                 return '您似乎准备用游戏昵称查询水表，请检查参数中是否包含服务器和游戏昵称，以空格区分'
         else:
             return '参数似乎出了问题呢'
-        print(params)
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
-            resp = await client.get(url, params=params, timeout=10)
+            resp = await client.get(url, params=params, timeout=20)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-info-recent.html")
@@ -80,9 +83,9 @@ async def get_RecentInfo(qqid,info):
         elif result['code'] == 404:
             return f"{result['message']}"
         elif result['code'] == 500:
-            return f"{result['message']}"
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
     except Exception:
-        traceback.print_exc()
+        logger.error(traceback.format_exc())
         return
\ No newline at end of file
