@@ -1,17 +1,19 @@
 from typing import List
 import httpx
 import traceback
-import json
 import jinja2
 import re
 import asyncio
 from pathlib import Path
-from .data_source import servers,set_shipparams
-from .utils import html_to_pic,match_keywords
+from .data_source import servers,set_shipparams,tiers
+from .utils import match_keywords
+from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
+from nonebot.adapters.onebot.v11 import MessageSegment
 from .wws_info import get_AccountIdByName
 from.publicAPI import get_ship_byName
 from collections import defaultdict, namedtuple
 from nonebot import get_driver
+from nonebot.log import logger
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
@@ -28,7 +30,7 @@ SecletProcess = defaultdict(lambda: ShipSlectState(False, None, None))
 
 async def get_ShipInfo(qqid,info,bot):
     try:
-        params = None
+        url,params = '',''
         if isinstance(info,List):
             for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
                 if i == 'me':
@@ -46,10 +48,8 @@ async def get_ShipInfo(qqid,info,bot):
                     "accountId": match.group(1),
                     }
                     info[flag] = str(i).replace(f"[{match.group(0)}]",'')
-                    print(f"info删除前{info}")
                     if not info[flag]:
                         info.remove('')
-                        print(f"info删除后{info}")
                     break
             if not params and len(info) == 3:
                 param_server,info = await match_keywords(info,servers)
@@ -63,11 +63,11 @@ async def get_ShipInfo(qqid,info,bot):
                         "accountId": param_accountid,
                         }
                     else:
-                        return '无法查询该游戏昵称Orz，请检查昵称是否存在，或尝试将船名放在最后'
+                        return '无法查询该游戏昵称Orz，请检查昵称是否存在，也有可能是网络波动，请稍后再试，或尝试将船名放在最后'
                 else:
                     return '服务器参数似乎输错了呢'
             elif params:
-                print('下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦')
+                print(params)
             else:
                 return '您似乎准备用游戏昵称查询单船战绩，请检查参数中是否包含服务器、游戏昵称和船名，以空格区分'
             shipList = await get_ship_byName(str(info[0]))
@@ -76,13 +76,14 @@ async def get_ShipInfo(qqid,info,bot):
                 if len(shipList) < 2:
                     params["shipId"] = shipList[0][0]
                 else:
-                    msg = f'存在多条名字相似的船，请在二十秒内选择对应的序号\n'
+                    msg = f'存在多条名字相似的船\n请在20秒内选择对应的序号\n=================\n'
                     flag = 0
                     for each in shipList:
                         flag += 1
-                        msg += f"{flag}：({each[3]}级) {each[1]}\n"
+                        msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
                     SecletProcess[qqid] = ShipSlectState(False, None, shipList)
-                    await bot.send(msg)
+                    img = await text_to_pic(text=msg,width=230)
+                    await bot.send(MessageSegment.image(img))
                     a = 0
                     while a < 200 and not SecletProcess[qqid].state:
                         a += 1
@@ -95,9 +96,10 @@ async def get_ShipInfo(qqid,info,bot):
                 return '找不到船'
         else:
             return '参数似乎出了问题呢'
-        print(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{params}")
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{url}\n{params}")
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=20)
+            logger.info(f"下面是本次请求返回的状态码，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{resp.status_code}")
             result = resp.json()
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-ship.html")
@@ -107,9 +109,9 @@ async def get_ShipInfo(qqid,info,bot):
         elif result['code'] == 404:
             return f"{result['message']}"
         elif result['code'] == 500:
-            return f"{result['message']}"
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
             return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'
     except Exception:
-        traceback.print_exc()
+        logger.error(traceback.format_exc())
         return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
\ No newline at end of file
